@@ -21,18 +21,16 @@ fn poisson_generator_processor_with_capacity() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
             String::from("processor-01"),
             Box::new(Processor::new(
                 ContinuousRandomVariable::Exp { lambda: 0.333333 },
-                14,
+                Some(14),
                 String::from("job"),
                 String::from("processed"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -42,7 +40,6 @@ fn poisson_generator_processor_with_capacity() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -128,7 +125,6 @@ fn step_until_activities() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -138,7 +134,6 @@ fn step_until_activities() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -178,18 +173,16 @@ fn non_stationary_generation() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
             String::from("processor-01"),
             Box::new(Processor::new(
                 ContinuousRandomVariable::Exp { lambda: 0.1659 },
-                14,
+                Some(14),
                 String::from("job"),
                 String::from("processed"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -199,7 +192,6 @@ fn non_stationary_generation() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -258,7 +250,6 @@ fn exclusive_gateway_proportions_chi_square() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -283,7 +274,6 @@ fn exclusive_gateway_proportions_chi_square() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -293,7 +283,6 @@ fn exclusive_gateway_proportions_chi_square() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -303,7 +292,6 @@ fn exclusive_gateway_proportions_chi_square() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -384,7 +372,6 @@ fn gate_blocking_proportions() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -394,7 +381,6 @@ fn gate_blocking_proportions() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -404,7 +390,6 @@ fn gate_blocking_proportions() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -424,7 +409,6 @@ fn gate_blocking_proportions() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -504,7 +488,6 @@ fn load_balancer_round_robin_outputs() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -517,7 +500,6 @@ fn load_balancer_round_robin_outputs() {
                     String::from("server-3"),
                 ],
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -527,7 +509,6 @@ fn load_balancer_round_robin_outputs() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -537,7 +518,6 @@ fn load_balancer_round_robin_outputs() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -547,7 +527,6 @@ fn load_balancer_round_robin_outputs() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -615,7 +594,6 @@ fn injection_initiated_stored_value_exchange() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -625,7 +603,6 @@ fn injection_initiated_stored_value_exchange() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -689,7 +666,6 @@ fn parallel_gateway_splits_and_joins() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -702,7 +678,6 @@ fn parallel_gateway_splits_and_joins() {
                     String::from("delta"),
                 ],
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -715,7 +690,6 @@ fn parallel_gateway_splits_and_joins() {
                 ],
                 vec![String::from("out")],
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -725,7 +699,6 @@ fn parallel_gateway_splits_and_joins() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -800,7 +773,6 @@ fn match_status_reporting() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -813,7 +785,6 @@ fn match_status_reporting() {
                     String::from("delta"),
                 ],
                 false,
-                false,
             )),
         ),
     ];
@@ -839,7 +810,6 @@ fn stochastic_gate_blocking() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -849,7 +819,6 @@ fn stochastic_gate_blocking() {
                 String::from("job"),
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -859,7 +828,6 @@ fn stochastic_gate_blocking() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
@@ -909,7 +877,6 @@ fn batch_sizing() {
                 None,
                 String::from("job"),
                 false,
-                false,
             )),
         ),
         Model::new(
@@ -928,7 +895,6 @@ fn batch_sizing() {
                 String::from("read"),
                 String::from("stored"),
                 false,
-                false,
             )),
         ),
     ];
